# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/console_tenant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import blobstorage_config_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__config__pb2
from ydb.public.api.protos import ydb_cms_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__cms__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/console_tenant.proto\x12\x0eNKikimrConsole\x1a(ydb/core/protos/blobstorage_config.proto\x1a#ydb/public/api/protos/ydb_cms.proto\x1a)ydb/public/api/protos/ydb_operation.proto\"Z\n\x14TCreateTenantRequest\x12/\n\x07Request\x18\x01 \x01(\x0b\x32\x1e.Ydb.Cms.CreateDatabaseRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"J\n\x15TCreateTenantResponse\x12\x31\n\x08Response\x18\x01 \x01(\x0b\x32\x1f.Ydb.Cms.CreateDatabaseResponse\"`\n\x17TGetTenantStatusRequest\x12\x32\n\x07Request\x18\x01 \x01(\x0b\x32!.Ydb.Cms.GetDatabaseStatusRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"P\n\x18TGetTenantStatusResponse\x12\x34\n\x08Response\x18\x01 \x01(\x0b\x32\".Ydb.Cms.GetDatabaseStatusResponse\"X\n\x13TAlterTenantRequest\x12.\n\x07Request\x18\x01 \x01(\x0b\x32\x1d.Ydb.Cms.AlterDatabaseRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"H\n\x14TAlterTenantResponse\x12\x30\n\x08Response\x18\x01 \x01(\x0b\x32\x1e.Ydb.Cms.AlterDatabaseResponse\"X\n\x13TListTenantsRequest\x12.\n\x07Request\x18\x01 \x01(\x0b\x32\x1d.Ydb.Cms.ListDatabasesRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"H\n\x14TListTenantsResponse\x12\x30\n\x08Response\x18\x01 \x01(\x0b\x32\x1e.Ydb.Cms.ListDatabasesResponse\"Z\n\x14TRemoveTenantRequest\x12/\n\x07Request\x18\x01 \x01(\x0b\x32\x1e.Ydb.Cms.RemoveDatabaseRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"J\n\x15TRemoveTenantResponse\x12\x31\n\x08Response\x18\x01 \x01(\x0b\x32\x1f.Ydb.Cms.RemoveDatabaseResponse\"_\n\x14TGetOperationRequest\x12\x34\n\x07Request\x18\x01 \x01(\x0b\x32#.Ydb.Operations.GetOperationRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"O\n\x15TGetOperationResponse\x12\x36\n\x08Response\x18\x01 \x01(\x0b\x32$.Ydb.Operations.GetOperationResponse\"l\n\x1dTDescribeTenantOptionsRequest\x12\x38\n\x07Request\x18\x01 \x01(\x0b\x32\'.Ydb.Cms.DescribeDatabaseOptionsRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"\\\n\x1eTDescribeTenantOptionsResponse\x12:\n\x08Response\x18\x01 \x01(\x0b\x32(.Ydb.Cms.DescribeDatabaseOptionsResponse\"\x86\x01\n\x17TUpdateTenantPoolConfig\x12\x0e\n\x06Tenant\x18\x01 \x01(\t\x12\x10\n\x08PoolType\x18\x02 \x01(\t\x12\x36\n\x06\x43onfig\x18\x03 \x01(\x0b\x32&.NKikimrBlobStorage.TDefineStoragePool\x12\x11\n\tUserToken\x18\x04 \x01(\x0c\"t\n\rTSlotLocation\x12\x12\n\nDataCenter\x18\x01 \x01(\t\x12\x1b\n\rForceLocation\x18\x02 \x01(\x08:\x04true\x12\x18\n\x10\x43ollocationGroup\x18\x03 \x01(\r\x12\x18\n\x10\x46orceCollocation\x18\x04 \x01(\x08\"~\n\x15TAvailabilityZoneKind\x12\x0c\n\x04Kind\x18\x01 \x01(\t\x12\x18\n\x0e\x44\x61taCenterName\x18\x02 \x01(\tH\x00\x12\x35\n\x0cSlotLocation\x18\x03 \x01(\x0b\x32\x1d.NKikimrConsole.TSlotLocationH\x00\x42\x06\n\x04Zone\"7\n\x14TAvailabilityZoneSet\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x11\n\tZoneKinds\x18\x02 \x03(\t\"i\n\x16TComputationalUnitKind\x12\x0c\n\x04Kind\x18\x01 \x01(\t\x12\x18\n\x0eTenantSlotType\x18\x02 \x01(\tH\x00\x12\x1b\n\x13\x41vailabilityZoneSet\x18\n \x01(\tB\n\n\x08Resource\"k\n\rTClusterQuota\x12#\n\x1b\x43omputationalUnitsLoadQuota\x18\x01 \x01(\x04\x12\x1f\n\x17\x43omputationalUnitsQuota\x18\x02 \x01(\x04\x12\x14\n\x0cTenantsQuota\x18\x03 \x01(\x04\"\xe1\x02\n\x0eTTenantsConfig\x12 \n\x18\x44\x65\x66\x61ultStorageUnitsQuota\x18\x01 \x01(\x04\x12&\n\x1e\x44\x65\x66\x61ultComputationalUnitsQuota\x18\x02 \x01(\x04\x12\x44\n\x15\x41vailabilityZoneKinds\x18\x03 \x03(\x0b\x32%.NKikimrConsole.TAvailabilityZoneKind\x12\x42\n\x14\x41vailabilityZoneSets\x18\x04 \x03(\x0b\x32$.NKikimrConsole.TAvailabilityZoneSet\x12\x46\n\x16\x43omputationalUnitKinds\x18\x05 \x03(\x0b\x32&.NKikimrConsole.TComputationalUnitKind\x12\x33\n\x0c\x43lusterQuota\x18\x06 \x01(\x0b\x32\x1d.NKikimrConsole.TClusterQuotaB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.console_tenant_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TCREATETENANTREQUEST._serialized_start=178
  _TCREATETENANTREQUEST._serialized_end=268
  _TCREATETENANTRESPONSE._serialized_start=270
  _TCREATETENANTRESPONSE._serialized_end=344
  _TGETTENANTSTATUSREQUEST._serialized_start=346
  _TGETTENANTSTATUSREQUEST._serialized_end=442
  _TGETTENANTSTATUSRESPONSE._serialized_start=444
  _TGETTENANTSTATUSRESPONSE._serialized_end=524
  _TALTERTENANTREQUEST._serialized_start=526
  _TALTERTENANTREQUEST._serialized_end=614
  _TALTERTENANTRESPONSE._serialized_start=616
  _TALTERTENANTRESPONSE._serialized_end=688
  _TLISTTENANTSREQUEST._serialized_start=690
  _TLISTTENANTSREQUEST._serialized_end=778
  _TLISTTENANTSRESPONSE._serialized_start=780
  _TLISTTENANTSRESPONSE._serialized_end=852
  _TREMOVETENANTREQUEST._serialized_start=854
  _TREMOVETENANTREQUEST._serialized_end=944
  _TREMOVETENANTRESPONSE._serialized_start=946
  _TREMOVETENANTRESPONSE._serialized_end=1020
  _TGETOPERATIONREQUEST._serialized_start=1022
  _TGETOPERATIONREQUEST._serialized_end=1117
  _TGETOPERATIONRESPONSE._serialized_start=1119
  _TGETOPERATIONRESPONSE._serialized_end=1198
  _TDESCRIBETENANTOPTIONSREQUEST._serialized_start=1200
  _TDESCRIBETENANTOPTIONSREQUEST._serialized_end=1308
  _TDESCRIBETENANTOPTIONSRESPONSE._serialized_start=1310
  _TDESCRIBETENANTOPTIONSRESPONSE._serialized_end=1402
  _TUPDATETENANTPOOLCONFIG._serialized_start=1405
  _TUPDATETENANTPOOLCONFIG._serialized_end=1539
  _TSLOTLOCATION._serialized_start=1541
  _TSLOTLOCATION._serialized_end=1657
  _TAVAILABILITYZONEKIND._serialized_start=1659
  _TAVAILABILITYZONEKIND._serialized_end=1785
  _TAVAILABILITYZONESET._serialized_start=1787
  _TAVAILABILITYZONESET._serialized_end=1842
  _TCOMPUTATIONALUNITKIND._serialized_start=1844
  _TCOMPUTATIONALUNITKIND._serialized_end=1949
  _TCLUSTERQUOTA._serialized_start=1951
  _TCLUSTERQUOTA._serialized_end=2058
  _TTENANTSCONFIG._serialized_start=2061
  _TTENANTSCONFIG._serialized_end=2414
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/ydb_persqueue_cluster_discovery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;ydb/public/api/protos/ydb_persqueue_cluster_discovery.proto\x12\x1eYdb.PersQueue.ClusterDiscovery\x1a\x1bgoogle/protobuf/empty.proto\x1a)ydb/public/api/protos/ydb_operation.proto\"o\n\x12WriteSessionParams\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x11\n\tsource_id\x18\x02 \x01(\x0c\x12\x17\n\x0fpartition_group\x18\x03 \x01(\r\x12\x1e\n\x16preferred_cluster_name\x18\x04 \x01(\t\"@\n\x0b\x43lusterInfo\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tavailable\x18\x03 \x01(\x08\"|\n\x11ReadSessionParams\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x1b\n\x11mirror_to_cluster\x18\x02 \x01(\tH\x00\x12.\n\x0c\x61ll_original\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x42\x0b\n\tread_rule\"\xc3\x02\n\x14WriteSessionClusters\x12=\n\x08\x63lusters\x18\x01 \x03(\x0b\x32+.Ydb.PersQueue.ClusterDiscovery.ClusterInfo\x12n\n primary_cluster_selection_reason\x18\x02 \x01(\x0e\x32\x44.Ydb.PersQueue.ClusterDiscovery.WriteSessionClusters.SelectionReason\"|\n\x0fSelectionReason\x12 \n\x1cSELECTION_REASON_UNSPECIFIED\x10\x00\x12\x15\n\x11\x43LIENT_PREFERENCE\x10\x01\x12\x13\n\x0f\x43LIENT_LOCATION\x10\x02\x12\x1b\n\x17\x43ONSISTENT_DISTRIBUTION\x10\x03\"T\n\x13ReadSessionClusters\x12=\n\x08\x63lusters\x18\x01 \x03(\x0b\x32+.Ydb.PersQueue.ClusterDiscovery.ClusterInfo\"\x83\x02\n\x17\x44iscoverClustersRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12J\n\x0ewrite_sessions\x18\x02 \x03(\x0b\x32\x32.Ydb.PersQueue.ClusterDiscovery.WriteSessionParams\x12H\n\rread_sessions\x18\x03 \x03(\x0b\x32\x31.Ydb.PersQueue.ClusterDiscovery.ReadSessionParams\x12\x17\n\x0fminimal_version\x18\x04 \x01(\x03\"H\n\x18\x44iscoverClustersResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xd5\x01\n\x16\x44iscoverClustersResult\x12U\n\x17write_sessions_clusters\x18\x01 \x03(\x0b\x32\x34.Ydb.PersQueue.ClusterDiscovery.WriteSessionClusters\x12S\n\x16read_sessions_clusters\x18\x02 \x03(\x0b\x32\x33.Ydb.PersQueue.ClusterDiscovery.ReadSessionClusters\x12\x0f\n\x07version\x18\x03 \x01(\x03\x42/\n*com.yandex.ydb.persqueue.cluster_discovery\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.ydb_persqueue_cluster_discovery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.yandex.ydb.persqueue.cluster_discovery\370\001\001'
  _WRITESESSIONPARAMS._serialized_start=167
  _WRITESESSIONPARAMS._serialized_end=278
  _CLUSTERINFO._serialized_start=280
  _CLUSTERINFO._serialized_end=344
  _READSESSIONPARAMS._serialized_start=346
  _READSESSIONPARAMS._serialized_end=470
  _WRITESESSIONCLUSTERS._serialized_start=473
  _WRITESESSIONCLUSTERS._serialized_end=796
  _WRITESESSIONCLUSTERS_SELECTIONREASON._serialized_start=672
  _WRITESESSIONCLUSTERS_SELECTIONREASON._serialized_end=796
  _READSESSIONCLUSTERS._serialized_start=798
  _READSESSIONCLUSTERS._serialized_end=882
  _DISCOVERCLUSTERSREQUEST._serialized_start=885
  _DISCOVERCLUSTERSREQUEST._serialized_end=1144
  _DISCOVERCLUSTERSRESPONSE._serialized_start=1146
  _DISCOVERCLUSTERSRESPONSE._serialized_end=1218
  _DISCOVERCLUSTERSRESULT._serialized_start=1221
  _DISCOVERCLUSTERSRESULT._serialized_end=1434
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/draft/persqueue_error_codes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7ydb/public/api/protos/draft/persqueue_error_codes.proto\x12\x15NPersQueue.NErrorCode*\xef\x04\n\nEErrorCode\x12\x06\n\x02OK\x10\x00\x12\x10\n\x0cINITIALIZING\x10\x01\x12\x0c\n\x08OVERLOAD\x10\x02\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x03\x12\x10\n\x0cWRONG_COOKIE\x10\x04\x12\x14\n\x10SOURCEID_DELETED\x10\x18\x12!\n\x1dWRITE_ERROR_PARTITION_IS_FULL\x10\x05\x12\x1c\n\x18WRITE_ERROR_DISK_IS_FULL\x10\x0f\x12\x1a\n\x16WRITE_ERROR_BAD_OFFSET\x10\x13\x12!\n\x1d\x43REATE_SESSION_ALREADY_LOCKED\x10\x06\x12\x1d\n\x19\x44\x45LETE_SESSION_NO_SESSION\x10\x07\x12\x1a\n\x16READ_ERROR_IN_PROGRESS\x10\x08\x12\x19\n\x15READ_ERROR_NO_SESSION\x10\t\x12\x10\n\x0cREAD_TIMEOUT\x10\n\x12\x1f\n\x1bREAD_ERROR_TOO_SMALL_OFFSET\x10\x0b\x12\x1d\n\x19READ_ERROR_TOO_BIG_OFFSET\x10\x0c\x12%\n!SET_OFFSET_ERROR_COMMIT_TO_FUTURE\x10\r\x12\x15\n\x11TABLET_IS_DROPPED\x10\x0e\x12\x11\n\rREAD_NOT_DONE\x10\x10\x12\x11\n\rUNKNOWN_TOPIC\x10\x11\x12\x11\n\rACCESS_DENIED\x10\x12\x12\x14\n\x10\x43LUSTER_DISABLED\x10\x14\x12\x1a\n\x16WRONG_PARTITION_NUMBER\x10\x15\x12\x12\n\x0e\x43REATE_TIMEOUT\x10\x16\x12\x10\n\x0cIDLE_TIMEOUT\x10\x17\x12\t\n\x05\x45RROR\x10\x64\x42\x1a\n\x18\x63om.yandex.ydb.persqueueb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.draft.persqueue_error_codes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.yandex.ydb.persqueue'
  _EERRORCODE._serialized_start=83
  _EERRORCODE._serialized_end=706
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tenant_slot_broker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ydb/core/protos/tenant_slot_broker.proto\x12\x17NKikimrTenantSlotBroker\x1a&library/cpp/actors/protos/actors.proto\"/\n\x07TConfig\x12$\n\x12PendingSlotTimeout\x18\x01 \x01(\x04:\x08\x31\x35\x30\x30\x30\x30\x30\x30\"\xaa\x01\n\x0fTSlotAllocation\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12\x15\n\rDataCenterNum\x18\x02 \x01(\x04\x12\x12\n\nDataCenter\x18\x07 \x01(\t\x12\r\n\x05\x43ount\x18\x03 \x01(\x04\x12\x1b\n\rForceLocation\x18\x04 \x01(\x08:\x04true\x12\x18\n\x10\x43ollocationGroup\x18\x05 \x01(\r\x12\x18\n\x10\x46orceCollocation\x18\x06 \x01(\x08\"%\n\x0fTGetTenantState\x12\x12\n\nTenantName\x18\x01 \x01(\t\"\xdb\x03\n\x0cTTenantState\x12\x12\n\nTenantName\x18\x01 \x01(\t\x12?\n\rRequiredSlots\x18\x02 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\x12>\n\x0cPendingSlots\x18\x03 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\x12>\n\x0cMissingSlots\x18\x04 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\x12@\n\x0eMisplacedSlots\x18\x05 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\x12<\n\nSplitSlots\x18\x06 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\x12=\n\x0bPinnedSlots\x18\x07 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\x12\x37\n\rAssignedSlots\x18\x08 \x03(\x0b\x32 .NKikimrTenantSlotBroker.TSlotId\"c\n\x0cTAlterTenant\x12\x12\n\nTenantName\x18\x01 \x01(\t\x12?\n\rRequiredSlots\x18\x02 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\"H\n\rTRegisterPool\x12(\n\x08\x43lientId\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\"\x0e\n\x0cTListTenants\"F\n\x0cTTenantsList\x12\x36\n\x07Tenants\x18\x01 \x03(\x0b\x32%.NKikimrTenantSlotBroker.TTenantState\"\x0f\n\rTGetSlotStats\"R\n\rTSlotCounters\x12\x12\n\nDataCenter\x18\x01 \x01(\t\x12\x0c\n\x04Type\x18\x02 \x01(\t\x12\x11\n\tConnected\x18\x03 \x01(\x04\x12\x0c\n\x04\x46ree\x18\x04 \x01(\x04\"J\n\nTSlotStats\x12<\n\x0cSlotCounters\x18\x01 \x03(\x0b\x32&.NKikimrTenantSlotBroker.TSlotCounters\")\n\x07TSlotId\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0e\n\x06SlotId\x18\x02 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tenant_slot_broker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TCONFIG._serialized_start=109
  _TCONFIG._serialized_end=156
  _TSLOTALLOCATION._serialized_start=159
  _TSLOTALLOCATION._serialized_end=329
  _TGETTENANTSTATE._serialized_start=331
  _TGETTENANTSTATE._serialized_end=368
  _TTENANTSTATE._serialized_start=371
  _TTENANTSTATE._serialized_end=846
  _TALTERTENANT._serialized_start=848
  _TALTERTENANT._serialized_end=947
  _TREGISTERPOOL._serialized_start=949
  _TREGISTERPOOL._serialized_end=1021
  _TLISTTENANTS._serialized_start=1023
  _TLISTTENANTS._serialized_end=1037
  _TTENANTSLIST._serialized_start=1039
  _TTENANTSLIST._serialized_end=1109
  _TGETSLOTSTATS._serialized_start=1111
  _TGETSLOTSTATS._serialized_end=1126
  _TSLOTCOUNTERS._serialized_start=1128
  _TSLOTCOUNTERS._serialized_end=1210
  _TSLOTSTATS._serialized_start=1212
  _TSLOTSTATS._serialized_end=1286
  _TSLOTID._serialized_start=1288
  _TSLOTID._serialized_end=1329
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx_mediator_timecast.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ydb/core/protos/tx_mediator_timecast.proto\x12\x19NKikimrTxMediatorTimecast\"\x1a\n\x08TEvWatch\x12\x0e\n\x06\x42ucket\x18\x01 \x03(\r\"U\n\tTEvUpdate\x12\x10\n\x08Mediator\x18\x01 \x01(\x04\x12\x0e\n\x06\x42ucket\x18\x02 \x01(\r\x12\x13\n\x0bTimeBarrier\x18\x04 \x01(\x06\x12\x11\n\tExemption\x18\x05 \x03(\x06\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_mediator_timecast_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEVWATCH._serialized_start=73
  _TEVWATCH._serialized_end=99
  _TEVUPDATE._serialized_start=101
  _TEVUPDATE._serialized_end=186
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/quotas_manager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3ydb/core/yq/libs/config/protos/quotas_manager.proto\x12\x0bNYq.NConfig\"*\n\x0bTQuotaLimit\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Limit\x18\x02 \x01(\x04\"]\n\nTQuotaList\x12\x13\n\x0bSubjectType\x18\x01 \x01(\t\x12\x11\n\tSubjectId\x18\x02 \x01(\t\x12\'\n\x05Limit\x18\x03 \x03(\x0b\x32\x18.NYq.NConfig.TQuotaLimit\"k\n\x17TQuotaDescriptionConfig\x12\x13\n\x0bSubjectType\x18\x01 \x01(\t\x12\x12\n\nMetricName\x18\x02 \x01(\t\x12\x14\n\x0c\x44\x65\x66\x61ultLimit\x18\x03 \x01(\x04\x12\x11\n\tHardLimit\x18\x04 \x01(\x04\"\xe4\x01\n\x14TQuotasManagerConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\'\n\x06Quotas\x18\x02 \x03(\x0b\x32\x17.NYq.NConfig.TQuotaList\x12?\n\x11QuotaDescriptions\x18\x03 \x03(\x0b\x32$.NYq.NConfig.TQuotaDescriptionConfig\x12\x1a\n\x12LimitRefreshPeriod\x18\x04 \x01(\t\x12\x1a\n\x12UsageRefreshPeriod\x18\x05 \x01(\t\x12\x19\n\x11\x45nablePermissions\x18\x06 \x01(\x08\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.quotas_manager_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TQUOTALIMIT._serialized_start=68
  _TQUOTALIMIT._serialized_end=110
  _TQUOTALIST._serialized_start=112
  _TQUOTALIST._serialized_end=205
  _TQUOTADESCRIPTIONCONFIG._serialized_start=207
  _TQUOTADESCRIPTIONCONFIG._serialized_end=314
  _TQUOTASMANAGERCONFIG._serialized_start=317
  _TQUOTASMANAGERCONFIG._serialized_end=545
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/grpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import msgbus_pb2 as ydb_dot_core_dot_protos_dot_msgbus__pb2
from ydb.core.protos import msgbus_kv_pb2 as ydb_dot_core_dot_protos_dot_msgbus__kv__pb2
from ydb.core.protos import msgbus_pq_pb2 as ydb_dot_core_dot_protos_dot_msgbus__pq__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aydb/core/protos/grpc.proto\x12\rNKikimrClient\x1a\x1cydb/core/protos/msgbus.proto\x1a\x1fydb/core/protos/msgbus_kv.proto\x1a\x1fydb/core/protos/msgbus_pq.proto2\xd3\x13\n\x0bTGRpcServer\x12<\n\x07Request\x12\x17.NKikimrClient.TRequest\x1a\x18.NKikimrClient.TResponse\x12L\n\x0fSchemeOperation\x12\x1f.NKikimrClient.TSchemeOperation\x1a\x18.NKikimrClient.TResponse\x12X\n\x15SchemeOperationStatus\x12%.NKikimrClient.TSchemeOperationStatus\x1a\x18.NKikimrClient.TResponse\x12J\n\x0eSchemeDescribe\x12\x1e.NKikimrClient.TSchemeDescribe\x1a\x18.NKikimrClient.TResponse\x12:\n\x06WhoAmI\x12\x16.NKikimrClient.TWhoAmI\x1a\x18.NKikimrClient.TResponse\x12\x46\n\x0cLoginRequest\x12\x1c.NKikimrClient.TLoginRequest\x1a\x18.NKikimrClient.TResponse\x12K\n\x0b\x43hooseProxy\x12\".NKikimrClient.TChooseProxyRequest\x1a\x18.NKikimrClient.TResponse\x12N\n\x10PersQueueRequest\x12 .NKikimrClient.TPersQueueRequest\x1a\x18.NKikimrClient.TResponse\x12J\n\x0eSchemeInitRoot\x12\x1e.NKikimrClient.TSchemeInitRoot\x1a\x18.NKikimrClient.TResponse\x12\x38\n\x05\x42SAdm\x12\x15.NKikimrClient.TBSAdm\x1a\x18.NKikimrClient.TResponse\x12K\n\x0bResolveNode\x12\".NKikimrClient.TResolveNodeRequest\x1a\x18.NKikimrClient.TResponse\x12\x45\n\x08\x46illNode\x12\x1f.NKikimrClient.TFillNodeRequest\x1a\x18.NKikimrClient.TResponse\x12G\n\tDrainNode\x12 .NKikimrClient.TDrainNodeRequest\x1a\x18.NKikimrClient.TResponse\x12W\n\x11\x42lobStorageConfig\x12(.NKikimrClient.TBlobStorageConfigRequest\x1a\x18.NKikimrClient.TResponse\x12N\n\x10HiveCreateTablet\x12 .NKikimrClient.THiveCreateTablet\x1a\x18.NKikimrClient.TResponse\x12X\n\x15LocalEnumerateTablets\x12%.NKikimrClient.TLocalEnumerateTablets\x1a\x18.NKikimrClient.TResponse\x12\x45\n\x08KeyValue\x12\x1f.NKikimrClient.TKeyValueRequest\x1a\x18.NKikimrClient.TResponse\x12U\n\x10TestShardControl\x12\'.NKikimrClient.TTestShardControlRequest\x1a\x18.NKikimrClient.TResponse\x12\x61\n\x0cRegisterNode\x12\'.NKikimrClient.TNodeRegistrationRequest\x1a(.NKikimrClient.TNodeRegistrationResponse\x12\x45\n\nCmsRequest\x12\x1a.NKikimrClient.TCmsRequest\x1a\x1b.NKikimrClient.TCmsResponse\x12\x45\n\nSqsRequest\x12\x1a.NKikimrClient.TSqsRequest\x1a\x1b.NKikimrClient.TSqsResponse\x12Q\n\x0e\x43onsoleRequest\x12\x1e.NKikimrClient.TConsoleRequest\x1a\x1f.NKikimrClient.TConsoleResponse\x12@\n\tLocalMKQL\x12\x19.NKikimrClient.TLocalMKQL\x1a\x18.NKikimrClient.TResponse\x12H\n\rLocalSchemeTx\x12\x1d.NKikimrClient.TLocalSchemeTx\x1a\x18.NKikimrClient.TResponse\x12P\n\x11TabletKillRequest\x12!.NKikimrClient.TTabletKillRequest\x1a\x18.NKikimrClient.TResponse\x12P\n\x11InterconnectDebug\x12!.NKikimrClient.TInterconnectDebug\x1a\x18.NKikimrClient.TResponse\x12R\n\x12TabletStateRequest\x12\".NKikimrClient.TTabletStateRequest\x1a\x18.NKikimrClient.TResponse\x12U\n\x16\x42lobStorageLoadRequest\x12!.NKikimrClient.TBsTestLoadRequest\x1a\x18.NKikimrClient.TResponse\x12O\n\x15\x42lobStorageGetRequest\x12\x1c.NKikimrClient.TBsGetRequest\x1a\x18.NKikimrClient.TResponse\x12S\n\x14\x44\x61taShardLoadRequest\x12!.NKikimrClient.TDsTestLoadRequest\x1a\x18.NKikimrClient.TResponse\x12\x36\n\x08\x44\x62Schema\x12\x14.NKikimrClient.TJSON\x1a\x14.NKikimrClient.TJSON\x12\x39\n\x0b\x44\x62Operation\x12\x14.NKikimrClient.TJSON\x1a\x14.NKikimrClient.TJSON\x12\x35\n\x07\x44\x62\x42\x61tch\x12\x14.NKikimrClient.TJSON\x1a\x14.NKikimrClient.TJSONb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.grpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TGRPCSERVER._serialized_start=142
  _TGRPCSERVER._serialized_end=2657
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_vdisk_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ydb/core/protos/blobstorage_vdisk_config.proto\x12\x12NKikimrBlobStorage\"\xc1\x03\n\x0cTVDiskConfig\x12\x1d\n\x15\x46reshBufSizeLogoBlobs\x18\n \x01(\x04\x12\x1c\n\x14\x46reshBufSizeBarriers\x18\x0b \x01(\x04\x12\x1a\n\x12\x46reshBufSizeBlocks\x18\x0c \x01(\x04\x12#\n\x1b\x46reshCompThresholdLogoBlobs\x18\r \x01(\x04\x12\"\n\x1a\x46reshCompThresholdBarriers\x18\x0e \x01(\x04\x12 \n\x18\x46reshCompThresholdBlocks\x18\x0f \x01(\x04\x12\x1a\n\x12\x46reshReadReadyMode\x18\x14 \x01(\x08\x12\x14\n\x0c\x46reshUseDreg\x18\x15 \x01(\x08\x12\x16\n\x0e\x41llowKeepFlags\x18( \x01(\x08\x12#\n\x1bHullCompLevel0MaxSstsAtOnce\x18- \x01(\r\x12\x1e\n\x16HullCompSortedPartsNum\x18. \x01(\r\x12\x1f\n\x17ReplInterconnectChannel\x18\x32 \x01(\r\x12\x19\n\x11\x42\x61rrierValidation\x18< \x01(\x08\x12\"\n\x1a\x45nableOverseerLsnReporting\x18= \x01(\x08\"\xb9\x02\n\nTVDiskKind\x12\x37\n\x04Kind\x18\x01 \x01(\x0e\x32).NKikimrBlobStorage.TVDiskKind.EVDiskKind\x12;\n\x08\x42\x61seKind\x18\x02 \x01(\x0e\x32).NKikimrBlobStorage.TVDiskKind.EVDiskKind\x12\x30\n\x06\x43onfig\x18\x03 \x01(\x0b\x32 .NKikimrBlobStorage.TVDiskConfig\"\x82\x01\n\nEVDiskKind\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\t\n\x05Test1\x10\x01\x12\t\n\x05Test2\x10\x02\x12\t\n\x05Test3\x10\x03\x12\x07\n\x03Log\x10\n\x12\r\n\tLocalMode\x10\x0b\x12\n\n\x06\x45xtra2\x10\x16\x12\n\n\x06\x45xtra3\x10\x17\x12\n\n\x06\x45xtra4\x10\x18\x12\n\n\x06\x45xtra5\x10\x19\"D\n\x0eTAllVDiskKinds\x12\x32\n\nVDiskKinds\x18\x01 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TVDiskKind\"\xb0\x01\n\x0fTIncrHugeConfig\x12\"\n\x12MinHugeBlobInBytes\x18\x01 \x01(\r:\x06\x35\x30\x30\x30\x30\x30\x12\x19\n\x0eMinCleanChunks\x18\x02 \x01(\r:\x01\x38\x12\x1d\n\x12MinAllocationBatch\x18\x03 \x01(\r:\x01\x34\x12!\n\x12UnalignedBlockSize\x18\x04 \x01(\r:\x05\x35\x30\x30\x30\x30\x12\x1c\n\x11MaxInFlightWrites\x18\x05 \x01(\r:\x01\x35\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_vdisk_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TVDISKCONFIG._serialized_start=71
  _TVDISKCONFIG._serialized_end=520
  _TVDISKKIND._serialized_start=523
  _TVDISKKIND._serialized_end=836
  _TVDISKKIND_EVDISKKIND._serialized_start=706
  _TVDISKKIND_EVDISKKIND._serialized_end=836
  _TALLVDISKKINDS._serialized_start=838
  _TALLVDISKKINDS._serialized_end=906
  _TINCRHUGECONFIG._serialized_start=909
  _TINCRHUGECONFIG._serialized_end=1085
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/draft/ydb_query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos.annotations import validation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_annotations_dot_validation__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_query_stats_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__query__stats__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_value_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ydb/public/api/protos/draft/ydb_query.proto\x12\tYdb.Query\x1a\x32ydb/public/api/protos/annotations/validation.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a)ydb/public/api/protos/ydb_operation.proto\x1a+ydb/public/api/protos/ydb_query_stats.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a%ydb/public/api/protos/ydb_value.proto\"\x1c\n\x14\x43reateSessionRequestJ\x04\x08\x01\x10\x02\"\xa3\x01\n\x15\x43reateSessionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x1b\n\nsession_id\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x19\n\x07node_id\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"3\n\x14\x44\x65leteSessionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"k\n\x15\x44\x65leteSessionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"1\n\x12PingSessionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\x9b\x01\n\x13PingSessionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x30\n\x0esession_status\x18\x03 \x01(\x0e\x32\x18.Ydb.Query.SessionStatus\"\x1a\n\x18SerializableModeSettings\"6\n\x12OnlineModeSettings\x12 \n\x18\x61llow_inconsistent_reads\x18\x01 \x01(\x08\"\x13\n\x11StaleModeSettings\"\x16\n\x14SnapshotModeSettings\"\x9b\x02\n\x13TransactionSettings\x12\x46\n\x17serializable_read_write\x18\x01 \x01(\x0b\x32#.Ydb.Query.SerializableModeSettingsH\x00\x12\x39\n\x10online_read_only\x18\x02 \x01(\x0b\x32\x1d.Ydb.Query.OnlineModeSettingsH\x00\x12\x37\n\x0fstale_read_only\x18\x03 \x01(\x0b\x32\x1c.Ydb.Query.StaleModeSettingsH\x00\x12=\n\x12snapshot_read_only\x18\x04 \x01(\x0b\x32\x1f.Ydb.Query.SnapshotModeSettingsH\x00\x42\t\n\x07tx_mode\"\x84\x01\n\x12TransactionControl\x12\x18\n\x05tx_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x00\x12\x32\n\x08\x62\x65gin_tx\x18\x02 \x01(\x0b\x32\x1e.Ydb.Query.TransactionSettingsH\x00\x12\x11\n\tcommit_tx\x18\n \x01(\x08\x42\r\n\x0btx_selector\"k\n\x17\x42\x65ginTransactionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x33\n\x0btx_settings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Query.TransactionSettings\"&\n\x0fTransactionMeta\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\x9b\x01\n\x18\x42\x65ginTransactionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12+\n\x07tx_meta\x18\x03 \x01(\x0b\x32\x1a.Ydb.Query.TransactionMeta\"O\n\x18\x43ommitTransactionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x16\n\x05tx_id\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"o\n\x19\x43ommitTransactionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"Q\n\x1aRollbackTransactionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x16\n\x05tx_id\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"q\n\x1bRollbackTransactionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"?\n\x0cQueryContent\x12!\n\x06syntax\x18\x01 \x01(\x0e\x32\x11.Ydb.Query.Syntax\x12\x0c\n\x04text\x18\x02 \x01(\t\"\x9e\x03\n\x13\x45xecuteQueryRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12&\n\texec_mode\x18\x02 \x01(\x0e\x32\x13.Ydb.Query.ExecMode\x12\x31\n\ntx_control\x18\x03 \x01(\x0b\x32\x1d.Ydb.Query.TransactionControl\x12\x30\n\rquery_content\x18\x04 \x01(\x0b\x32\x17.Ydb.Query.QueryContentH\x00\x12\x42\n\nparameters\x18\x06 \x03(\x0b\x32..Ydb.Query.ExecuteQueryRequest.ParametersEntry\x12(\n\nstats_mode\x18\x08 \x01(\x0e\x32\x14.Ydb.Query.StatsMode\x12\x1c\n\x14parallel_result_sets\x18\t \x01(\x08\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\x42\x07\n\x05queryJ\x04\x08\x07\x10\x08\"-\n\rResultSetMeta\x12\x1c\n\x07\x63olumns\x18\x01 \x03(\x0b\x32\x0b.Ydb.Column\"\xc7\x02\n\x18\x45xecuteQueryResponsePart\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\"\n\x10result_set_index\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\"\n\nresult_set\x18\x04 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12+\n\x07tx_meta\x18\x05 \x01(\x0b\x32\x1a.Ydb.Query.TransactionMeta\x12\x32\n\x10result_sets_meta\x18\x06 \x03(\x0b\x32\x18.Ydb.Query.ResultSetMeta\x12.\n\nexec_stats\x18\x07 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"@\n\rSavedScriptId\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1a\n\x08revision\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"\x8d\x05\n\x14\x45xecuteScriptRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\nsession_id\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12&\n\texec_mode\x18\x04 \x01(\x0e\x32\x13.Ydb.Query.ExecMode\x12\x31\n\x0escript_content\x18\x05 \x01(\x0b\x32\x17.Ydb.Query.QueryContentH\x00\x12-\n\tscript_id\x18\x06 \x01(\x0b\x32\x18.Ydb.Query.SavedScriptIdH\x00\x12\x43\n\nparameters\x18\x07 \x03(\x0b\x32/.Ydb.Query.ExecuteScriptRequest.ParametersEntry\x12\x12\n\npersistent\x18\x08 \x01(\x08\x12\x1f\n\x0e\x65xecution_name\x18\t \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12(\n\nstats_mode\x18\x0b \x01(\x0e\x32\x14.Ydb.Query.StatsMode\x12\\\n\nattributes\x18\x0c \x03(\x0b\x32/.Ydb.Query.ExecuteScriptRequest.AttributesEntryB\x17\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x07\n\x05\x08\x01\x10\x80 \x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06scriptJ\x04\x08\x03\x10\x04J\x04\x08\n\x10\x0bJ\x04\x08\r\x10\x0e\"\xeb\x03\n\x15\x45xecuteScriptMetadata\x12\x1d\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12*\n\x0b\x65xec_status\x18\x02 \x01(\x0e\x32\x15.Ydb.Query.ExecStatus\x12\x31\n\x0escript_content\x18\x03 \x01(\x0b\x32\x17.Ydb.Query.QueryContentH\x00\x12-\n\tscript_id\x18\x04 \x01(\x0b\x32\x18.Ydb.Query.SavedScriptIdH\x00\x12]\n\nattributes\x18\x05 \x03(\x0b\x32\x30.Ydb.Query.ExecuteScriptMetadata.AttributesEntryB\x17\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x07\n\x05\x08\x01\x10\x80 \x12\x31\n\x0fresult_set_meta\x18\x06 \x03(\x0b\x32\x18.Ydb.Query.ResultSetMeta\x12&\n\texec_mode\x18\x07 \x01(\x0e\x32\x13.Ydb.Query.ExecMode\x12.\n\nexec_stats\x18\x08 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06script\"\xa0\x01\n\x19\x46\x65tchScriptResultsRequest\x12\x1d\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1e\n\x0b\x66\x65tch_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x00\x12\x1d\n\x0brows_offset\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x1c\n\nrows_limit\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0B\x07\n\x05\x66\x65tch\"\xdb\x01\n\x1a\x46\x65tchScriptResultsResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\"\n\x10result_set_index\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\"\n\nresult_set\x18\x04 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12!\n\x10next_fetch_token\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"]\n\x0bSavedScript\x12$\n\x02id\x18\x01 \x01(\x0b\x32\x18.Ydb.Query.SavedScriptId\x12(\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x17.Ydb.Query.QueryContent\"=\n\x11SaveScriptRequest\x12(\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x17.Ydb.Query.QueryContent\"\x95\x01\n\x12SaveScriptResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12+\n\tscript_id\x18\x03 \x01(\x0b\x32\x18.Ydb.Query.SavedScriptId\"N\n\x12ListScriptsRequest\x12\x1b\n\npage_token\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\tpage_size\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"\xb4\x01\n\x13ListScriptsResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\'\n\x07scripts\x18\x03 \x03(\x0b\x32\x16.Ydb.Query.SavedScript\x12 \n\x0fnext_page_token\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"B\n\x13\x44\x65leteScriptRequest\x12+\n\tscript_id\x18\x01 \x01(\x0b\x32\x18.Ydb.Query.SavedScriptId\"j\n\x14\x44\x65leteScriptResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage*b\n\rSessionStatus\x12\x1e\n\x1aSESSION_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14SESSION_STATUS_READY\x10\x01\x12\x17\n\x13SESSION_STATUS_BUSY\x10\x02*B\n\x06Syntax\x12\x16\n\x12SYNTAX_UNSPECIFIED\x10\x00\x12\x11\n\rSYNTAX_YQL_V1\x10\x01\x12\r\n\tSYNTAX_PG\x10\x02*\x86\x01\n\x08\x45xecMode\x12\x19\n\x15\x45XEC_MODE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x45XEC_MODE_PARSE\x10\n\x12\x16\n\x12\x45XEC_MODE_VALIDATE\x10\x14\x12\x15\n\x11\x45XEC_MODE_EXPLAIN\x10\x1e\x12\x15\n\x11\x45XEC_MODE_EXECUTE\x10\x03\"\x04\x08\x04\x10\x04*\x7f\n\tStatsMode\x12\x1a\n\x16STATS_MODE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSTATS_MODE_NONE\x10\x01\x12\x14\n\x10STATS_MODE_BASIC\x10\x02\x12\x13\n\x0fSTATS_MODE_FULL\x10\x03\x12\x16\n\x12STATS_MODE_PROFILE\x10\x04*\xaa\x01\n\nExecStatus\x12\x1b\n\x17\x45XEC_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14\x45XEC_STATUS_STARTING\x10\n\x12\x17\n\x13\x45XEC_STATUS_ABORTED\x10\x14\x12\x19\n\x15\x45XEC_STATUS_CANCELLED\x10\x1e\x12\x19\n\x15\x45XEC_STATUS_COMPLETED\x10(\x12\x16\n\x12\x45XEC_STATUS_FAILED\x10\x32\x42&\n\x14\x63om.yandex.ydb.queryB\x0bQueryProtos\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.draft.ydb_query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.yandex.ydb.queryB\013QueryProtos\370\001\001'
  _CREATESESSIONRESPONSE.fields_by_name['session_id']._options = None
  _CREATESESSIONRESPONSE.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _CREATESESSIONRESPONSE.fields_by_name['node_id']._options = None
  _CREATESESSIONRESPONSE.fields_by_name['node_id']._serialized_options = b'\262\346*\004>= 0'
  _DELETESESSIONREQUEST.fields_by_name['session_id']._options = None
  _DELETESESSIONREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _PINGSESSIONREQUEST.fields_by_name['session_id']._options = None
  _PINGSESSIONREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _TRANSACTIONCONTROL.fields_by_name['tx_id']._options = None
  _TRANSACTIONCONTROL.fields_by_name['tx_id']._serialized_options = b'\242\346*\003\030\200\010'
  _BEGINTRANSACTIONREQUEST.fields_by_name['session_id']._options = None
  _BEGINTRANSACTIONREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _TRANSACTIONMETA.fields_by_name['id']._options = None
  _TRANSACTIONMETA.fields_by_name['id']._serialized_options = b'\242\346*\003\030\200\010'
  _COMMITTRANSACTIONREQUEST.fields_by_name['session_id']._options = None
  _COMMITTRANSACTIONREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _COMMITTRANSACTIONREQUEST.fields_by_name['tx_id']._options = None
  _COMMITTRANSACTIONREQUEST.fields_by_name['tx_id']._serialized_options = b'\242\346*\003\030\200\010'
  _ROLLBACKTRANSACTIONREQUEST.fields_by_name['session_id']._options = None
  _ROLLBACKTRANSACTIONREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _ROLLBACKTRANSACTIONREQUEST.fields_by_name['tx_id']._options = None
  _ROLLBACKTRANSACTIONREQUEST.fields_by_name['tx_id']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTEQUERYREQUEST_PARAMETERSENTRY._options = None
  _EXECUTEQUERYREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _EXECUTEQUERYREQUEST.fields_by_name['session_id']._options = None
  _EXECUTEQUERYREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTEQUERYRESPONSEPART.fields_by_name['result_set_index']._options = None
  _EXECUTEQUERYRESPONSEPART.fields_by_name['result_set_index']._serialized_options = b'\262\346*\004>= 0'
  _SAVEDSCRIPTID.fields_by_name['id']._options = None
  _SAVEDSCRIPTID.fields_by_name['id']._serialized_options = b'\242\346*\003\030\200\010'
  _SAVEDSCRIPTID.fields_by_name['revision']._options = None
  _SAVEDSCRIPTID.fields_by_name['revision']._serialized_options = b'\262\346*\004>= 0'
  _EXECUTESCRIPTREQUEST_PARAMETERSENTRY._options = None
  _EXECUTESCRIPTREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _EXECUTESCRIPTREQUEST_ATTRIBUTESENTRY._options = None
  _EXECUTESCRIPTREQUEST_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _EXECUTESCRIPTREQUEST.fields_by_name['session_id']._options = None
  _EXECUTESCRIPTREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTESCRIPTREQUEST.fields_by_name['execution_name']._options = None
  _EXECUTESCRIPTREQUEST.fields_by_name['execution_name']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTESCRIPTREQUEST.fields_by_name['attributes']._options = None
  _EXECUTESCRIPTREQUEST.fields_by_name['attributes']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\007\n\005\010\001\020\200 '
  _EXECUTESCRIPTMETADATA_ATTRIBUTESENTRY._options = None
  _EXECUTESCRIPTMETADATA_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _EXECUTESCRIPTMETADATA.fields_by_name['execution_id']._options = None
  _EXECUTESCRIPTMETADATA.fields_by_name['execution_id']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTESCRIPTMETADATA.fields_by_name['attributes']._options = None
  _EXECUTESCRIPTMETADATA.fields_by_name['attributes']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\007\n\005\010\001\020\200 '
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['execution_id']._options = None
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['execution_id']._serialized_options = b'\242\346*\003\030\200\010'
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['fetch_token']._options = None
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['fetch_token']._serialized_options = b'\242\346*\003\030\200\010'
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['rows_offset']._options = None
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['rows_offset']._serialized_options = b'\262\346*\004>= 0'
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['rows_limit']._options = None
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['rows_limit']._serialized_options = b'\262\346*\004>= 0'
  _FETCHSCRIPTRESULTSRESPONSE.fields_by_name['result_set_index']._options = None
  _FETCHSCRIPTRESULTSRESPONSE.fields_by_name['result_set_index']._serialized_options = b'\262\346*\004>= 0'
  _FETCHSCRIPTRESULTSRESPONSE.fields_by_name['next_fetch_token']._options = None
  _FETCHSCRIPTRESULTSRESPONSE.fields_by_name['next_fetch_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTSCRIPTSREQUEST.fields_by_name['page_token']._options = None
  _LISTSCRIPTSREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTSCRIPTSREQUEST.fields_by_name['page_size']._options = None
  _LISTSCRIPTSREQUEST.fields_by_name['page_size']._serialized_options = b'\262\346*\004>= 0'
  _LISTSCRIPTSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTSCRIPTSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _SESSIONSTATUS._serialized_start=5355
  _SESSIONSTATUS._serialized_end=5453
  _SYNTAX._serialized_start=5455
  _SYNTAX._serialized_end=5521
  _EXECMODE._serialized_start=5524
  _EXECMODE._serialized_end=5658
  _STATSMODE._serialized_start=5660
  _STATSMODE._serialized_end=5787
  _EXECSTATUS._serialized_start=5790
  _EXECSTATUS._serialized_end=5960
  _CREATESESSIONREQUEST._serialized_start=330
  _CREATESESSIONREQUEST._serialized_end=358
  _CREATESESSIONRESPONSE._serialized_start=361
  _CREATESESSIONRESPONSE._serialized_end=524
  _DELETESESSIONREQUEST._serialized_start=526
  _DELETESESSIONREQUEST._serialized_end=577
  _DELETESESSIONRESPONSE._serialized_start=579
  _DELETESESSIONRESPONSE._serialized_end=686
  _PINGSESSIONREQUEST._serialized_start=688
  _PINGSESSIONREQUEST._serialized_end=737
  _PINGSESSIONRESPONSE._serialized_start=740
  _PINGSESSIONRESPONSE._serialized_end=895
  _SERIALIZABLEMODESETTINGS._serialized_start=897
  _SERIALIZABLEMODESETTINGS._serialized_end=923
  _ONLINEMODESETTINGS._serialized_start=925
  _ONLINEMODESETTINGS._serialized_end=979
  _STALEMODESETTINGS._serialized_start=981
  _STALEMODESETTINGS._serialized_end=1000
  _SNAPSHOTMODESETTINGS._serialized_start=1002
  _SNAPSHOTMODESETTINGS._serialized_end=1024
  _TRANSACTIONSETTINGS._serialized_start=1027
  _TRANSACTIONSETTINGS._serialized_end=1310
  _TRANSACTIONCONTROL._serialized_start=1313
  _TRANSACTIONCONTROL._serialized_end=1445
  _BEGINTRANSACTIONREQUEST._serialized_start=1447
  _BEGINTRANSACTIONREQUEST._serialized_end=1554
  _TRANSACTIONMETA._serialized_start=1556
  _TRANSACTIONMETA._serialized_end=1594
  _BEGINTRANSACTIONRESPONSE._serialized_start=1597
  _BEGINTRANSACTIONRESPONSE._serialized_end=1752
  _COMMITTRANSACTIONREQUEST._serialized_start=1754
  _COMMITTRANSACTIONREQUEST._serialized_end=1833
  _COMMITTRANSACTIONRESPONSE._serialized_start=1835
  _COMMITTRANSACTIONRESPONSE._serialized_end=1946
  _ROLLBACKTRANSACTIONREQUEST._serialized_start=1948
  _ROLLBACKTRANSACTIONREQUEST._serialized_end=2029
  _ROLLBACKTRANSACTIONRESPONSE._serialized_start=2031
  _ROLLBACKTRANSACTIONRESPONSE._serialized_end=2144
  _QUERYCONTENT._serialized_start=2146
  _QUERYCONTENT._serialized_end=2209
  _EXECUTEQUERYREQUEST._serialized_start=2212
  _EXECUTEQUERYREQUEST._serialized_end=2626
  _EXECUTEQUERYREQUEST_PARAMETERSENTRY._serialized_start=2545
  _EXECUTEQUERYREQUEST_PARAMETERSENTRY._serialized_end=2611
  _RESULTSETMETA._serialized_start=2628
  _RESULTSETMETA._serialized_end=2673
  _EXECUTEQUERYRESPONSEPART._serialized_start=2676
  _EXECUTEQUERYRESPONSEPART._serialized_end=3003
  _SAVEDSCRIPTID._serialized_start=3005
  _SAVEDSCRIPTID._serialized_end=3069
  _EXECUTESCRIPTREQUEST._serialized_start=3072
  _EXECUTESCRIPTREQUEST._serialized_end=3725
  _EXECUTESCRIPTREQUEST_PARAMETERSENTRY._serialized_start=2545
  _EXECUTESCRIPTREQUEST_PARAMETERSENTRY._serialized_end=2611
  _EXECUTESCRIPTREQUEST_ATTRIBUTESENTRY._serialized_start=3648
  _EXECUTESCRIPTREQUEST_ATTRIBUTESENTRY._serialized_end=3697
  _EXECUTESCRIPTMETADATA._serialized_start=3728
  _EXECUTESCRIPTMETADATA._serialized_end=4219
  _EXECUTESCRIPTMETADATA_ATTRIBUTESENTRY._serialized_start=3648
  _EXECUTESCRIPTMETADATA_ATTRIBUTESENTRY._serialized_end=3697
  _FETCHSCRIPTRESULTSREQUEST._serialized_start=4222
  _FETCHSCRIPTRESULTSREQUEST._serialized_end=4382
  _FETCHSCRIPTRESULTSRESPONSE._serialized_start=4385
  _FETCHSCRIPTRESULTSRESPONSE._serialized_end=4604
  _SAVEDSCRIPT._serialized_start=4606
  _SAVEDSCRIPT._serialized_end=4699
  _SAVESCRIPTREQUEST._serialized_start=4701
  _SAVESCRIPTREQUEST._serialized_end=4762
  _SAVESCRIPTRESPONSE._serialized_start=4765
  _SAVESCRIPTRESPONSE._serialized_end=4914
  _LISTSCRIPTSREQUEST._serialized_start=4916
  _LISTSCRIPTSREQUEST._serialized_end=4994
  _LISTSCRIPTSRESPONSE._serialized_start=4997
  _LISTSCRIPTSRESPONSE._serialized_end=5177
  _DELETESCRIPTREQUEST._serialized_start=5179
  _DELETESCRIPTREQUEST._serialized_end=5245
  _DELETESCRIPTRESPONSE._serialized_start=5247
  _DELETESCRIPTRESPONSE._serialized_end=5353
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_coordinator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ydb/core/protos/counters_coordinator.proto\x12\x1aNKikimr.NFlatTxCoordinator\x1a\x1eydb/core/protos/counters.proto*,\n\x0f\x45SimpleCounters\x12\x19\n\x15\x43OUNTER_SIMPLE_IGNORE\x10\x00*W\n\x13\x45\x43umulativeCounters\x12@\n\x1d\x43OUNTER_REQ_ACQUIRE_READ_STEP\x10\x00\x1a\x1d\x82\xd6\x1b\x19\n\x17\x41\x63quireReadStepRequests*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*\xf1\x02\n\x08\x45TxTypes\x12\x1d\n\x0bTXTYPE_INIT\x10\x00\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12\x1d\n\x0bTXTYPE_STEP\x10\x01\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxStep\x12@\n\x1dTXTYPE_MEDIATOR_CONFIRMATIONS\x10\x02\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxMediatorConfirmations\x12\x34\n\x17TXTYPE_RESTART_MEDIATOR\x10\x03\x1a\x17\x8a\xd6\x1b\x13\n\x11TxRestartMediator\x12\x35\n\x18TXTYPE_ACQUIRE_READ_STEP\x10\x04\x1a\x17\x8a\xd6\x1b\x13\n\x11TxAcquireReadStep\x12\x39\n\x1aTXTYPE_SUBSCRIBE_READ_STEP\x10\x05\x1a\x19\x8a\xd6\x1b\x15\n\x13TxSubscribeReadStep\x12=\n\x1cTXTYPE_UNSUBSCRIBE_READ_STEP\x10\x06\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxUnsubscribeReadStepB\'\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x0b\x43oordinator')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_coordinator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\013Coordinator'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQ_ACQUIRE_READ_STEP"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQ_ACQUIRE_READ_STEP"]._serialized_options = b'\202\326\033\031\n\027AcquireReadStepRequests'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_STEP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STEP"]._serialized_options = b'\212\326\033\010\n\006TxStep'
  _ETXTYPES.values_by_name["TXTYPE_MEDIATOR_CONFIRMATIONS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MEDIATOR_CONFIRMATIONS"]._serialized_options = b'\212\326\033\031\n\027TxMediatorConfirmations'
  _ETXTYPES.values_by_name["TXTYPE_RESTART_MEDIATOR"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESTART_MEDIATOR"]._serialized_options = b'\212\326\033\023\n\021TxRestartMediator'
  _ETXTYPES.values_by_name["TXTYPE_ACQUIRE_READ_STEP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ACQUIRE_READ_STEP"]._serialized_options = b'\212\326\033\023\n\021TxAcquireReadStep'
  _ETXTYPES.values_by_name["TXTYPE_SUBSCRIBE_READ_STEP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SUBSCRIBE_READ_STEP"]._serialized_options = b'\212\326\033\025\n\023TxSubscribeReadStep'
  _ETXTYPES.values_by_name["TXTYPE_UNSUBSCRIBE_READ_STEP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UNSUBSCRIBE_READ_STEP"]._serialized_options = b'\212\326\033\027\n\025TxUnsubscribeReadStep'
  _ESIMPLECOUNTERS._serialized_start=106
  _ESIMPLECOUNTERS._serialized_end=150
  _ECUMULATIVECOUNTERS._serialized_start=152
  _ECUMULATIVECOUNTERS._serialized_end=239
  _EPERCENTILECOUNTERS._serialized_start=241
  _EPERCENTILECOUNTERS._serialized_end=319
  _ETXTYPES._serialized_start=322
  _ETXTYPES._serialized_end=691
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/protos/clickhouse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.yql.protos import common_pb2 as ydb_dot_library_dot_yql_dot_protos_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ydb/library/yql/protos/clickhouse.proto\x12\x0bNYql.NProto\x1a#ydb/library/yql/protos/common.proto\"\x86\x01\n\x17TClickHouseRunnerConfig\x12\x1b\n\rMaxResultRows\x18\x03 \x01(\r:\x04\x31\x30\x30\x30\x12 \n\x0eMaxResultBytes\x18\x04 \x01(\r:\x08\x33\x30\x30\x30\x30\x30\x30\x30\x12,\n\x10MaxExecutionTime\x18\x05 \x01(\x0b\x32\x12.NYql.NProto.TTimeB\x15\n\x13ru.yandex.yql.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.protos.clickhouse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023ru.yandex.yql.proto'
  _TCLICKHOUSERUNNERCONFIG._serialized_start=94
  _TCLICKHOUSERUNNERCONFIG._serialized_end=228
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/scheme_board.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import flat_tx_scheme_pb2 as ydb_dot_core_dot_protos_dot_flat__tx__scheme__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/scheme_board.proto\x12\x12NKikimrSchemeBoard\x1a$ydb/core/protos/flat_tx_scheme.proto\"/\n\x11TLocalPathIdRange\x12\r\n\x05\x42\x65gin\x18\x01 \x01(\x04\x12\x0b\n\x03\x45nd\x18\x02 \x01(\x04\"1\n\x0cTEvHandshake\x12\r\n\x05Owner\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\"\xe8\x02\n\tTEvUpdate\x12\r\n\x05Owner\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x42\n\x13\x44\x65letedLocalPathIds\x18\x03 \x01(\x0b\x32%.NKikimrSchemeBoard.TLocalPathIdRange\x12\x0c\n\x04Path\x18\x04 \x01(\t\x12\x13\n\x0bLocalPathId\x18\x05 \x01(\x04\x12\x19\n\nIsDeletion\x18\x06 \x01(\x08:\x05\x66\x61lse\x12\x44\n\x14\x44\x65scribeSchemeResult\x18\x07 \x01(\x0b\x32&.NKikimrScheme.TEvDescribeSchemeResult\x12\x16\n\x07NeedAck\x18\x08 \x01(\x08:\x05\x66\x61lse\x12\x13\n\x0bPathOwnerId\x18\t \x01(\x04\x12\x43\n\x14MigratedLocalPathIds\x18\n \x01(\x0b\x32%.NKikimrSchemeBoard.TLocalPathIdRange\"l\n\x0cTEvUpdateAck\x12\r\n\x05Owner\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x03 \x01(\x04\x12\x0f\n\x07Version\x18\x04 \x01(\x04\x12\x13\n\x0bPathOwnerId\x18\x05 \x01(\x04\"8\n\x13TEvCommitGeneration\x12\r\n\x05Owner\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\"\xd5\x01\n\x0cTEvSubscribe\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x13\n\x0bPathOwnerId\x18\x02 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x03 \x01(\x04\x12\x15\n\rDomainOwnerId\x18\x04 \x01(\x04\x12\x44\n\x0c\x43\x61pabilities\x18\x05 \x01(\x0b\x32..NKikimrSchemeBoard.TEvSubscribe.TCapabilities\x1a\x30\n\rTCapabilities\x12\x1f\n\x10\x41\x63kNotifications\x18\x01 \x01(\x08:\x05\x66\x61lse\"H\n\x0eTEvUnsubscribe\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x13\n\x0bPathOwnerId\x18\x02 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x03 \x01(\x04\"\xcc\x01\n\tTEvNotify\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x13\n\x0bPathOwnerId\x18\x02 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x03 \x01(\x04\x12\x19\n\nIsDeletion\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x44\n\x14\x44\x65scribeSchemeResult\x18\x05 \x01(\x0b\x32&.NKikimrScheme.TEvDescribeSchemeResult\x12\x0f\n\x07Version\x18\x06 \x01(\x04\x12\x15\n\x06Strong\x18\x07 \x01(\x08:\x05\x66\x61lse\"\x1f\n\x0cTEvNotifyAck\x12\x0f\n\x07Version\x18\x01 \x01(\x04\"O\n\x15TEvSyncVersionRequest\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x13\n\x0bPathOwnerId\x18\x02 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x03 \x01(\x04\":\n\x16TEvSyncVersionResponse\x12\x0f\n\x07Version\x18\x01 \x01(\x04\x12\x0f\n\x07Partial\x18\x02 \x01(\x08\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.scheme_board_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TLOCALPATHIDRANGE._serialized_start=96
  _TLOCALPATHIDRANGE._serialized_end=143
  _TEVHANDSHAKE._serialized_start=145
  _TEVHANDSHAKE._serialized_end=194
  _TEVUPDATE._serialized_start=197
  _TEVUPDATE._serialized_end=557
  _TEVUPDATEACK._serialized_start=559
  _TEVUPDATEACK._serialized_end=667
  _TEVCOMMITGENERATION._serialized_start=669
  _TEVCOMMITGENERATION._serialized_end=725
  _TEVSUBSCRIBE._serialized_start=728
  _TEVSUBSCRIBE._serialized_end=941
  _TEVSUBSCRIBE_TCAPABILITIES._serialized_start=893
  _TEVSUBSCRIBE_TCAPABILITIES._serialized_end=941
  _TEVUNSUBSCRIBE._serialized_start=943
  _TEVUNSUBSCRIBE._serialized_end=1015
  _TEVNOTIFY._serialized_start=1018
  _TEVNOTIFY._serialized_end=1222
  _TEVNOTIFYACK._serialized_start=1224
  _TEVNOTIFYACK._serialized_end=1255
  _TEVSYNCVERSIONREQUEST._serialized_start=1257
  _TEVSYNCVERSIONREQUEST._serialized_end=1336
  _TEVSYNCVERSIONRESPONSE._serialized_start=1338
  _TEVSYNCVERSIONRESPONSE._serialized_end=1396
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_sysview_processor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ydb/core/protos/counters_sysview_processor.proto\x12\x10NKikimr.NSysView\x1a\x1eydb/core/protos/counters.proto*\xea\x02\n\x08\x45TxTypes\x12*\n\x12TXTYPE_INIT_SCHEMA\x10\x00\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitSchema\x12\x1d\n\x0bTXTYPE_INIT\x10\x01\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12\'\n\x10TXTYPE_CONFIGURE\x10\x02\x1a\x11\x8a\xd6\x1b\r\n\x0bTxConfigure\x12#\n\x0eTXTYPE_COLLECT\x10\x03\x1a\x0f\x8a\xd6\x1b\x0b\n\tTxCollect\x12\'\n\x10TXTYPE_AGGREGATE\x10\x04\x1a\x11\x8a\xd6\x1b\r\n\x0bTxAggregate\x12\x34\n\x17TXTYPE_INTERVAL_SUMMARY\x10\x05\x1a\x17\x8a\xd6\x1b\x13\n\x11TxIntervalSummary\x12\x34\n\x17TXTYPE_INTERVAL_METRICS\x10\x06\x1a\x17\x8a\xd6\x1b\x13\n\x11TxIntervalMetrics\x12\x30\n\x15TXTYPE_TOP_PARTITIONS\x10\x07\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxTopPartitionsB,\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x10SysViewProcessor')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_sysview_processor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\020SysViewProcessor'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\016\n\014TxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_CONFIGURE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIGURE"]._serialized_options = b'\212\326\033\r\n\013TxConfigure'
  _ETXTYPES.values_by_name["TXTYPE_COLLECT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COLLECT"]._serialized_options = b'\212\326\033\013\n\tTxCollect'
  _ETXTYPES.values_by_name["TXTYPE_AGGREGATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_AGGREGATE"]._serialized_options = b'\212\326\033\r\n\013TxAggregate'
  _ETXTYPES.values_by_name["TXTYPE_INTERVAL_SUMMARY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INTERVAL_SUMMARY"]._serialized_options = b'\212\326\033\023\n\021TxIntervalSummary'
  _ETXTYPES.values_by_name["TXTYPE_INTERVAL_METRICS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INTERVAL_METRICS"]._serialized_options = b'\212\326\033\023\n\021TxIntervalMetrics'
  _ETXTYPES.values_by_name["TXTYPE_TOP_PARTITIONS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_TOP_PARTITIONS"]._serialized_options = b'\212\326\033\021\n\017TxTopPartitions'
  _ETXTYPES._serialized_start=103
  _ETXTYPES._serialized_end=465
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_sequenceshard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/core/protos/counters_sequenceshard.proto\x12\x16NKikimr.NSequenceShard\x1a\x1eydb/core/protos/counters.proto*,\n\x0f\x45SimpleCounters\x12\x19\n\x15\x43OUNTER_SIMPLE_IGNORE\x10\x00*4\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*\x86\x04\n\x08\x45TxTypes\x12*\n\x12TXTYPE_INIT_SCHEMA\x10\x00\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitSchema\x12\x1d\n\x0bTXTYPE_INIT\x10\x01\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12=\n\x1cTXTYPE_MARK_SCHEMESHARD_PIPE\x10\x02\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxMarkSchemeShardPipe\x12\x32\n\x16TXTYPE_CREATE_SEQUENCE\x10\x03\x1a\x16\x8a\xd6\x1b\x12\n\x10TxCreateSequence\x12\x36\n\x18TXTYPE_ALLOCATE_SEQUENCE\x10\x04\x1a\x18\x8a\xd6\x1b\x14\n\x12TxAllocateSequence\x12.\n\x14TXTYPE_DROP_SEQUENCE\x10\x05\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxDropSequence\x12\x32\n\x16TXTYPE_UPDATE_SEQUENCE\x10\x06\x1a\x16\x8a\xd6\x1b\x12\n\x10TxUpdateSequence\x12\x32\n\x16TXTYPE_FREEZE_SEQUENCE\x10\x07\x1a\x16\x8a\xd6\x1b\x12\n\x10TxFreezeSequence\x12\x34\n\x17TXTYPE_RESTORE_SEQUENCE\x10\x08\x1a\x17\x8a\xd6\x1b\x13\n\x11TxRestoreSequence\x12\x36\n\x18TXTYPE_REDIRECT_SEQUENCE\x10\t\x1a\x18\x8a\xd6\x1b\x14\n\x12TxRedirectSequenceB)\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\rSequenceShard')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_sequenceshard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\rSequenceShard'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\016\n\014TxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_MARK_SCHEMESHARD_PIPE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MARK_SCHEMESHARD_PIPE"]._serialized_options = b'\212\326\033\027\n\025TxMarkSchemeShardPipe'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_SEQUENCE"]._serialized_options = b'\212\326\033\022\n\020TxCreateSequence'
  _ETXTYPES.values_by_name["TXTYPE_ALLOCATE_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ALLOCATE_SEQUENCE"]._serialized_options = b'\212\326\033\024\n\022TxAllocateSequence'
  _ETXTYPES.values_by_name["TXTYPE_DROP_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DROP_SEQUENCE"]._serialized_options = b'\212\326\033\020\n\016TxDropSequence'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_SEQUENCE"]._serialized_options = b'\212\326\033\022\n\020TxUpdateSequence'
  _ETXTYPES.values_by_name["TXTYPE_FREEZE_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FREEZE_SEQUENCE"]._serialized_options = b'\212\326\033\022\n\020TxFreezeSequence'
  _ETXTYPES.values_by_name["TXTYPE_RESTORE_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESTORE_SEQUENCE"]._serialized_options = b'\212\326\033\023\n\021TxRestoreSequence'
  _ETXTYPES.values_by_name["TXTYPE_REDIRECT_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REDIRECT_SEQUENCE"]._serialized_options = b'\212\326\033\024\n\022TxRedirectSequence'
  _ESIMPLECOUNTERS._serialized_start=104
  _ESIMPLECOUNTERS._serialized_end=148
  _ECUMULATIVECOUNTERS._serialized_start=150
  _ECUMULATIVECOUNTERS._serialized_end=202
  _EPERCENTILECOUNTERS._serialized_start=204
  _EPERCENTILECOUNTERS._serialized_end=282
  _ETXTYPES._serialized_start=285
  _ETXTYPES._serialized_end=803
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/resource_broker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ydb/core/protos/resource_broker.proto\x12\x15NKikimrResourceBroker\";\n\nTResources\x12\x10\n\x08Resource\x18\x01 \x03(\x04\x12\x0b\n\x03\x43pu\x18\x02 \x01(\x04\x12\x0e\n\x06Memory\x18\x03 \x01(\x04\"^\n\x0cTQueueConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06Weight\x18\x02 \x01(\r\x12\x30\n\x05Limit\x18\x03 \x01(\x0b\x32!.NKikimrResourceBroker.TResources\"G\n\x0bTTaskConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x17\n\x0f\x44\x65\x66\x61ultDuration\x18\x03 \x01(\x04\"\xb9\x01\n\x15TResourceBrokerConfig\x12\x33\n\x06Queues\x18\x01 \x03(\x0b\x32#.NKikimrResourceBroker.TQueueConfig\x12\x31\n\x05Tasks\x18\x02 \x03(\x0b\x32\".NKikimrResourceBroker.TTaskConfig\x12\x38\n\rResourceLimit\x18\x03 \x01(\x0b\x32!.NKikimrResourceBroker.TResources\"?\n\x1bTResourceBrokerConfigResult\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0f\n\x07Message\x18\x02 \x01(\t*$\n\rEResourceType\x12\x07\n\x03\x43PU\x10\x00\x12\n\n\x06MEMORY\x10\x01\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.resource_broker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ERESOURCETYPE._serialized_start=547
  _ERESOURCETYPE._serialized_end=583
  _TRESOURCES._serialized_start=64
  _TRESOURCES._serialized_end=123
  _TQUEUECONFIG._serialized_start=125
  _TQUEUECONFIG._serialized_end=219
  _TTASKCONFIG._serialized_start=221
  _TTASKCONFIG._serialized_end=292
  _TRESOURCEBROKERCONFIG._serialized_start=295
  _TRESOURCEBROKERCONFIG._serialized_end=480
  _TRESOURCEBROKERCONFIGRESULT._serialized_start=482
  _TRESOURCEBROKERCONFIGRESULT._serialized_end=545
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/http_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/http_config.proto\x12\rNKikimrConfig\"\x93\x01\n\x11THttpServerConfig\x12\x12\n\x04Port\x18\x01 \x01(\r:\x04\x38\x37\x37\x31\x12\x12\n\x07Threads\x18\x02 \x01(\r:\x01\x35\x12\x1c\n\x0eMaxConnections\x18\x03 \x01(\r:\x04\x31\x30\x30\x30\x12\x19\n\x0cMaxQueueSize\x18\x04 \x01(\r:\x03\x35\x30\x30\x12\x1d\n\x0f\x45nableKeepAlive\x18\x05 \x01(\x08:\x04trueB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.http_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _THTTPSERVERCONFIG._serialized_start=53
  _THTTPSERVERCONFIG._serialized_end=200
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/providers/s3/proto/source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ydb/library/yql/providers/s3/proto/source.proto\x12\x08NYql.NS3\"#\n\x05TPath\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0c\n\x04Size\x18\x02 \x01(\x04\"\x83\x02\n\x07TSource\x12\x0b\n\x03Url\x18\x01 \x01(\t\x12\r\n\x05Token\x18\x02 \x01(\t\x12\'\n\x0e\x44\x65precatedPath\x18\x03 \x03(\x0b\x32\x0f.NYql.NS3.TPath\x12\x14\n\x07RowType\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x46ormat\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x31\n\x08Settings\x18\x06 \x03(\x0b\x32\x1f.NYql.NS3.TSource.SettingsEntry\x12\r\n\x05\x41rrow\x18\x07 \x01(\x08\x1a/\n\rSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\n\n\x08_RowTypeB\t\n\x07_FormatB\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.providers.s3.proto.source_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TSOURCE_SETTINGSENTRY._options = None
  _TSOURCE_SETTINGSENTRY._serialized_options = b'8\001'
  _TPATH._serialized_start=61
  _TPATH._serialized_end=96
  _TSOURCE._serialized_start=99
  _TSOURCE._serialized_end=358
  _TSOURCE_SETTINGSENTRY._serialized_start=288
  _TSOURCE_SETTINGSENTRY._serialized_end=335
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx_columnshard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.core.protos import long_tx_service_pb2 as ydb_dot_core_dot_protos_dot_long__tx__service__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import ssa_pb2 as ydb_dot_core_dot_protos_dot_ssa__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/tx_columnshard.proto\x12\x14NKikimrTxColumnShard\x1a&library/cpp/actors/protos/actors.proto\x1a$ydb/core/protos/flat_scheme_op.proto\x1a%ydb/core/protos/long_tx_service.proto\x1a ydb/core/protos/subdomains.proto\x1a\x19ydb/core/protos/ssa.proto\"\xd8\x01\n\nTReadStats\x12\x16\n\x0e\x42\x65ginTimestamp\x18\x01 \x01(\x04\x12\x14\n\x0c\x44urationUsec\x18\x02 \x01(\x04\x12\x15\n\rSelectedIndex\x18\x03 \x01(\r\x12\x15\n\rIndexGranules\x18\x04 \x01(\x04\x12\x15\n\rIndexPortions\x18\x05 \x01(\x04\x12\x14\n\x0cIndexBatches\x18\x06 \x01(\x04\x12\x19\n\x11NotIndexedBatches\x18\x07 \x01(\x04\x12\x13\n\x0bUsedColumns\x18\x08 \x01(\r\x12\x11\n\tDataBytes\x18\t \x01(\x04\"\xbf\x01\n\x10TLogicalMetadata\x12\x0f\n\x07NumRows\x18\x01 \x01(\r\x12\x34\n\x0c\x46irstPkValue\x18\x02 \x03(\x0b\x32\x1e.NKikimrSSA.TProgram.TConstant\x12\x33\n\x0bLastPkValue\x18\x03 \x03(\x0b\x32\x1e.NKikimrSSA.TProgram.TConstant\x12\x10\n\x08RawBytes\x18\x04 \x01(\x04\x12\x1d\n\x15\x44irtyWriteTimeSeconds\x18\x05 \x01(\x04\"u\n\tTMetadata\x12\x0e\n\x06\x46ormat\x18\x01 \x01(\r\x12\x0e\n\x06Schema\x18\x02 \x01(\x0c\x12\x33\n\tReadStats\x18\x03 \x01(\x0b\x32 .NKikimrTxColumnShard.TReadStats\x12\x13\n\x0bLogicalMeta\x18\x04 \x01(\x0c\"7\n\x0eTEvictMetadata\x12\x10\n\x08TierName\x18\x01 \x01(\t\x12\x13\n\x0bTierVersion\x18\x02 \x01(\r\"\xea\x01\n\x08TEvWrite\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x13\n\x0bTxInitiator\x18\x02 \x01(\x04\x12\x0f\n\x07WriteId\x18\x03 \x01(\x04\x12\x0f\n\x07TableId\x18\x04 \x01(\x04\x12\x0f\n\x07\x44\x65\x64upId\x18\x05 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x06 \x01(\x0c\x12-\n\x04Meta\x18\x07 \x01(\x0b\x32\x1f.NKikimrTxColumnShard.TMetadata\x12\x31\n\x08LongTxId\x18\x08 \x01(\x0b\x32\x1f.NKikimrLongTxService.TLongTxId\"x\n\x0eTEvWriteResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x13\n\x0bTxInitiator\x18\x03 \x01(\x04\x12\x0f\n\x07WriteId\x18\x04 \x01(\x04\x12\x0f\n\x07TableId\x18\x05 \x01(\x04\x12\x0f\n\x07\x44\x65\x64upId\x18\x06 \x01(\t\"\xb8\x03\n\x07TEvRead\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x13\n\x0bTxInitiator\x18\x02 \x01(\x04\x12\x10\n\x08PlanStep\x18\x03 \x01(\x04\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\x12\x0f\n\x07TableId\x18\x05 \x01(\x04\x12\x11\n\tColumnIds\x18\x06 \x03(\r\x12\x13\n\x0b\x43olumnNames\x18\x07 \x03(\t\x12\x42\n\x10GreaterPredicate\x18\x08 \x01(\x0b\x32(.NKikimrTxColumnShard.TEvRead.TPredicate\x12?\n\rLessPredicate\x18\t \x01(\x0b\x32(.NKikimrTxColumnShard.TEvRead.TPredicate\x12\x13\n\x0bOlapProgram\x18\n \x01(\x0c\x12:\n\x0fOlapProgramType\x18\x0b \x01(\x0e\x32!.NKikimrSchemeOp.EOlapProgramType\x1a\x41\n\nTPredicate\x12\x13\n\x0b\x43olumnNames\x18\x01 \x03(\t\x12\x0b\n\x03Row\x18\x02 \x01(\x0c\x12\x11\n\tInclusive\x18\x03 \x01(\x08\"\xd3\x01\n\rTEvReadResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x13\n\x0bTxInitiator\x18\x03 \x01(\x04\x12\x10\n\x08PlanStep\x18\x04 \x01(\x04\x12\x0c\n\x04TxId\x18\x05 \x01(\x04\x12\x0f\n\x07TableId\x18\x06 \x01(\x04\x12\r\n\x05\x42\x61tch\x18\x07 \x01(\r\x12\x10\n\x08\x46inished\x18\x08 \x01(\x08\x12\x0c\n\x04\x44\x61ta\x18\t \x01(\x0c\x12-\n\x04Meta\x18\n \x01(\x0b\x32\x1f.NKikimrTxColumnShard.TMetadata\"\xec\x01\n\x15TEvProposeTransaction\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x36\n\x06TxKind\x18\x02 \x01(\x0e\x32&.NKikimrTxColumnShard.ETransactionKind\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x0e\n\x06TxBody\x18\x04 \x01(\x0c\x12\x15\n\rSchemeShardId\x18\x05 \x01(\x04\x12>\n\x10ProcessingParams\x18\x06 \x01(\x0b\x32$.NKikimrSubDomains.TProcessingParams\"\x8b\x02\n\x1bTEvProposeTransactionResult\x12\x33\n\x06Status\x18\x01 \x01(\x0e\x32#.NKikimrTxColumnShard.EResultStatus\x12\x36\n\x06TxKind\x18\x02 \x01(\x0e\x32&.NKikimrTxColumnShard.ETransactionKind\x12\x0e\n\x06Origin\x18\x03 \x01(\x04\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\x12\x0f\n\x07MinStep\x18\x05 \x01(\x04\x12\x0f\n\x07MaxStep\x18\x06 \x01(\x04\x12\x15\n\rStatusMessage\x18\x07 \x01(\t\x12\x1a\n\x12\x44omainCoordinators\x18\x08 \x03(\x06\x12\x0c\n\x04Step\x18\t \x01(\x04\",\n\x1cTEvCancelTransactionProposal\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"%\n\x15TEvNotifyTxCompletion\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\";\n\x1bTEvNotifyTxCompletionResult\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"6\n\rTCommitTxBody\x12\x13\n\x0bTxInitiator\x18\x01 \x01(\x04\x12\x10\n\x08WriteIds\x18\x02 \x03(\x04\"\x81\x01\n\x18TSchemaPresetVersionInfo\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x11\n\tSinceStep\x18\x02 \x01(\x04\x12\x11\n\tSinceTxId\x18\x03 \x01(\x04\x12\x33\n\x06Schema\x18\x04 \x01(\x0b\x32#.NKikimrSchemeOp.TColumnTableSchema\"\x8d\x01\n\x1dTTtlSettingsPresetVersionInfo\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x11\n\tSinceStep\x18\x02 \x01(\x04\x12\x11\n\tSinceTxId\x18\x03 \x01(\x04\x12:\n\x0bTtlSettings\x18\x04 \x01(\x0b\x32%.NKikimrSchemeOp.TColumnDataLifeCycle\"\xb4\x02\n\x11TTableVersionInfo\x12\x0e\n\x06PathId\x18\x01 \x01(\x04\x12\x11\n\tSinceStep\x18\x02 \x01(\x04\x12\x11\n\tSinceTxId\x18\x03 \x01(\x04\x12\x33\n\x06Schema\x18\x04 \x01(\x0b\x32#.NKikimrSchemeOp.TColumnTableSchema\x12\x16\n\x0eSchemaPresetId\x18\x05 \x01(\r\x12:\n\x0bTtlSettings\x18\x06 \x01(\x0b\x32%.NKikimrSchemeOp.TColumnDataLifeCycle\x12\x1b\n\x13TtlSettingsPresetId\x18\x07 \x01(\r\x12\x1e\n\x16SchemaPresetVersionAdj\x18\x08 \x01(\x04\x12#\n\x1bTtlSettingsPresetVersionAdj\x18\t \x01(\x04\"\xe0\x02\n\x0cTCreateTable\x12\x0e\n\x06PathId\x18\x01 \x01(\x04\x12\x33\n\x06Schema\x18\x02 \x01(\x0b\x32#.NKikimrSchemeOp.TColumnTableSchema\x12?\n\x0cSchemaPreset\x18\x03 \x01(\x0b\x32).NKikimrSchemeOp.TColumnTableSchemaPreset\x12:\n\x0bTtlSettings\x18\x04 \x01(\x0b\x32%.NKikimrSchemeOp.TColumnDataLifeCycle\x12I\n\x11TtlSettingsPreset\x18\x05 \x01(\x0b\x32..NKikimrSchemeOp.TColumnTableTtlSettingsPreset\x12\x1e\n\x16SchemaPresetVersionAdj\x18\x06 \x01(\x04\x12#\n\x1bTtlSettingsPresetVersionAdj\x18\x07 \x01(\x04\"\x82\x01\n\nTInitShard\x12\x18\n\x10\x44\x61taChannelCount\x18\x01 \x01(\r\x12\x13\n\x0bOwnerPathId\x18\x02 \x01(\x04\x12\x32\n\x06Tables\x18\x03 \x03(\x0b\x32\".NKikimrTxColumnShard.TCreateTable\x12\x11\n\tOwnerPath\x18\x04 \x01(\t\"\x96\x03\n\x0bTAlterTable\x12\x0e\n\x06PathId\x18\x01 \x01(\x04\x12\x35\n\tAlterBody\x18\x02 \x01(\x0b\x32\".NKikimrSchemeOp.TAlterColumnTable\x12\x33\n\x06Schema\x18\x03 \x01(\x0b\x32#.NKikimrSchemeOp.TColumnTableSchema\x12?\n\x0cSchemaPreset\x18\x04 \x01(\x0b\x32).NKikimrSchemeOp.TColumnTableSchemaPreset\x12:\n\x0bTtlSettings\x18\x05 \x01(\x0b\x32%.NKikimrSchemeOp.TColumnDataLifeCycle\x12I\n\x11TtlSettingsPreset\x18\x06 \x01(\x0b\x32..NKikimrSchemeOp.TColumnTableTtlSettingsPreset\x12\x1e\n\x16SchemaPresetVersionAdj\x18\x07 \x01(\x04\x12#\n\x1bTtlSettingsPresetVersionAdj\x18\x08 \x01(\x04\"\x1c\n\nTDropTable\x12\x0e\n\x06PathId\x18\x01 \x01(\x04\"C\n\rTEnsureTables\x12\x32\n\x06Tables\x18\x01 \x03(\x0b\x32\".NKikimrTxColumnShard.TCreateTable\"\x91\x02\n\x0bTAlterStore\x12\x35\n\tAlterBody\x18\x01 \x01(\x0b\x32\".NKikimrSchemeOp.TAlterColumnStore\x12\x1c\n\x14\x44roppedSchemaPresets\x18\x02 \x03(\r\x12@\n\rSchemaPresets\x18\x03 \x03(\x0b\x32).NKikimrSchemeOp.TColumnTableSchemaPreset\x12\x12\n\nReserved_4\x18\x04 \x03(\r\x12\x42\n\nReserved_5\x18\x05 \x03(\x0b\x32..NKikimrSchemeOp.TColumnTableTtlSettingsPreset\x12\x13\n\x0bStorePathId\x18\x06 \x01(\x04\"1\n\x0cTSchemaSeqNo\x12\x12\n\nGeneration\x18\x01 \x01(\r\x12\r\n\x05Round\x18\x02 \x01(\x04\"\x8f\x01\n\x11TIndexPortionMeta\x12\x14\n\nIsInserted\x18\x01 \x01(\x08H\x00\x12\x15\n\x0bIsCompacted\x18\x02 \x01(\x08H\x00\x12\x1a\n\x10IsSplitCompacted\x18\x03 \x01(\x08H\x00\x12\x13\n\tIsEvicted\x18\x04 \x01(\x08H\x00\x12\x10\n\x08TierName\x18\x05 \x01(\tB\n\n\x08Produced\"\xd7\x01\n\x10TIndexColumnMeta\x12\x0f\n\x07NumRows\x18\x01 \x01(\r\x12\x10\n\x08RawBytes\x18\x02 \x01(\r\x12\x30\n\x08MinValue\x18\x03 \x01(\x0b\x32\x1e.NKikimrSSA.TProgram.TConstant\x12\x30\n\x08MaxValue\x18\x04 \x01(\x0b\x32\x1e.NKikimrSSA.TProgram.TConstant\x12<\n\x0bPortionMeta\x18\x05 \x01(\x0b\x32\'.NKikimrTxColumnShard.TIndexPortionMeta\"\xe9\x02\n\rTSchemaTxBody\x12\x31\n\x05SeqNo\x18\x01 \x01(\x0b\x32\".NKikimrTxColumnShard.TSchemaSeqNo\x12\x35\n\tInitShard\x18\x02 \x01(\x0b\x32 .NKikimrTxColumnShard.TInitShardH\x00\x12;\n\x0c\x45nsureTables\x18\x03 \x01(\x0b\x32#.NKikimrTxColumnShard.TEnsureTablesH\x00\x12\x35\n\tDropTable\x18\x04 \x01(\x0b\x32 .NKikimrTxColumnShard.TDropTableH\x00\x12\x37\n\nAlterTable\x18\x05 \x01(\x0b\x32!.NKikimrTxColumnShard.TAlterTableH\x00\x12\x37\n\nAlterStore\x18\x06 \x01(\x0b\x32!.NKikimrTxColumnShard.TAlterStoreH\x00\x42\x08\n\x06TxBody\"y\n\nTTtlTxBody\x12\x15\n\rTtlColumnName\x18\x01 \x01(\t\x12\x17\n\x0fUnixTimeSeconds\x18\x02 \x01(\x04\x12\x13\n\x0bTtlPresetId\x18\x03 \x01(\r\x12\x15\n\rTtlPresetName\x18\x04 \x01(\t\x12\x0f\n\x07PathIds\x18\x05 \x03(\x04\":\n\nTBlobRange\x12\x0e\n\x06\x42lobId\x18\x01 \x01(\x0c\x12\x0e\n\x06Offset\x18\x02 \x01(\x04\x12\x0c\n\x04Size\x18\x03 \x01(\x04\"I\n\x11TEvReadBlobRanges\x12\x34\n\nBlobRanges\x18\x01 \x03(\x0b\x32 .NKikimrTxColumnShard.TBlobRange\"\xd1\x01\n\x17TEvReadBlobRangesResult\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x46\n\x07Results\x18\x02 \x03(\x0b\x32\x35.NKikimrTxColumnShard.TEvReadBlobRangesResult.TResult\x1a\\\n\x07TResult\x12\x33\n\tBlobRange\x18\x01 \x01(\x0b\x32 .NKikimrTxColumnShard.TBlobRange\x12\x0e\n\x06Status\x18\x02 \x01(\r\x12\x0c\n\x04\x44\x61ta\x18\x03 \x01(\x0c*\xb3\x01\n\rEResultStatus\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08PREPARED\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\x0b\n\x07\x41\x42ORTED\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x0b\n\x07TIMEOUT\x10\x05\x12\x0c\n\x08OUTDATED\x10\x06\x12\x10\n\x0cSCHEMA_ERROR\x10\x07\x12\x12\n\x0eSCHEMA_CHANGED\x10\x08\x12\x0e\n\nOVERLOADED\x10\t\x12\r\n\x07UNKNOWN\x10\xff\xff\x03*!\n\rEResultFormat\x12\x10\n\x0c\x46ORMAT_ARROW\x10\x01*]\n\x10\x45TransactionKind\x12\x10\n\x0cTX_KIND_NONE\x10\x00\x12\x12\n\x0eTX_KIND_SCHEMA\x10\x01\x12\x12\n\x0eTX_KIND_COMMIT\x10\x02\x12\x0f\n\x0bTX_KIND_TTL\x10\x03\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_columnshard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ERESULTSTATUS._serialized_start=5665
  _ERESULTSTATUS._serialized_end=5844
  _ERESULTFORMAT._serialized_start=5846
  _ERESULTFORMAT._serialized_end=5879
  _ETRANSACTIONKIND._serialized_start=5881
  _ETRANSACTIONKIND._serialized_end=5974
  _TREADSTATS._serialized_start=241
  _TREADSTATS._serialized_end=457
  _TLOGICALMETADATA._serialized_start=460
  _TLOGICALMETADATA._serialized_end=651
  _TMETADATA._serialized_start=653
  _TMETADATA._serialized_end=770
  _TEVICTMETADATA._serialized_start=772
  _TEVICTMETADATA._serialized_end=827
  _TEVWRITE._serialized_start=830
  _TEVWRITE._serialized_end=1064
  _TEVWRITERESULT._serialized_start=1066
  _TEVWRITERESULT._serialized_end=1186
  _TEVREAD._serialized_start=1189
  _TEVREAD._serialized_end=1629
  _TEVREAD_TPREDICATE._serialized_start=1564
  _TEVREAD_TPREDICATE._serialized_end=1629
  _TEVREADRESULT._serialized_start=1632
  _TEVREADRESULT._serialized_end=1843
  _TEVPROPOSETRANSACTION._serialized_start=1846
  _TEVPROPOSETRANSACTION._serialized_end=2082
  _TEVPROPOSETRANSACTIONRESULT._serialized_start=2085
  _TEVPROPOSETRANSACTIONRESULT._serialized_end=2352
  _TEVCANCELTRANSACTIONPROPOSAL._serialized_start=2354
  _TEVCANCELTRANSACTIONPROPOSAL._serialized_end=2398
  _TEVNOTIFYTXCOMPLETION._serialized_start=2400
  _TEVNOTIFYTXCOMPLETION._serialized_end=2437
  _TEVNOTIFYTXCOMPLETIONRESULT._serialized_start=2439
  _TEVNOTIFYTXCOMPLETIONRESULT._serialized_end=2498
  _TCOMMITTXBODY._serialized_start=2500
  _TCOMMITTXBODY._serialized_end=2554
  _TSCHEMAPRESETVERSIONINFO._serialized_start=2557
  _TSCHEMAPRESETVERSIONINFO._serialized_end=2686
  _TTTLSETTINGSPRESETVERSIONINFO._serialized_start=2689
  _TTTLSETTINGSPRESETVERSIONINFO._serialized_end=2830
  _TTABLEVERSIONINFO._serialized_start=2833
  _TTABLEVERSIONINFO._serialized_end=3141
  _TCREATETABLE._serialized_start=3144
  _TCREATETABLE._serialized_end=3496
  _TINITSHARD._serialized_start=3499
  _TINITSHARD._serialized_end=3629
  _TALTERTABLE._serialized_start=3632
  _TALTERTABLE._serialized_end=4038
  _TDROPTABLE._serialized_start=4040
  _TDROPTABLE._serialized_end=4068
  _TENSURETABLES._serialized_start=4070
  _TENSURETABLES._serialized_end=4137
  _TALTERSTORE._serialized_start=4140
  _TALTERSTORE._serialized_end=4413
  _TSCHEMASEQNO._serialized_start=4415
  _TSCHEMASEQNO._serialized_end=4464
  _TINDEXPORTIONMETA._serialized_start=4467
  _TINDEXPORTIONMETA._serialized_end=4610
  _TINDEXCOLUMNMETA._serialized_start=4613
  _TINDEXCOLUMNMETA._serialized_end=4828
  _TSCHEMATXBODY._serialized_start=4831
  _TSCHEMATXBODY._serialized_end=5192
  _TTTLTXBODY._serialized_start=5194
  _TTTLTXBODY._serialized_end=5315
  _TBLOBRANGE._serialized_start=5317
  _TBLOBRANGE._serialized_end=5375
  _TEVREADBLOBRANGES._serialized_start=5377
  _TEVREADBLOBRANGES._serialized_end=5450
  _TEVREADBLOBRANGESRESULT._serialized_start=5453
  _TEVREADBLOBRANGESRESULT._serialized_end=5662
  _TEVREADBLOBRANGESRESULT_TRESULT._serialized_start=5570
  _TEVREADBLOBRANGESRESULT_TRESULT._serialized_end=5662
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/scheme_type_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ydb/core/protos/scheme_type_metadata.proto\x12\x19NKikimrSchemeTypeMetadata\"\x99\x01\n\tTMetadata\x12\x38\n\x04Type\x18\x01 \x03(\x0b\x32*.NKikimrSchemeTypeMetadata.TMetadata.TType\x1aR\n\x05TType\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\x0c\x12\r\n\x05\x46lags\x18\x03 \x01(\r\x12\x0f\n\x07MaxSize\x18\x04 \x01(\r\x12\x0f\n\x07MinSize\x18\x05 \x01(\rB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.scheme_type_metadata_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TMETADATA._serialized_start=74
  _TMETADATA._serialized_end=227
  _TMETADATA_TTYPE._serialized_start=145
  _TMETADATA_TTYPE._serialized_end=227
# @@protoc_insertion_point(module_scope)



import ydb.apps.dstool.lib.grouptool as grouptool
import ydb.apps.dstool.lib.common as common
import ydb.apps.dstool.lib.table as table
import multiprocessing
import json
import sys
from collections import defaultdict

description = 'Estimate groups usage by tablets'


def create_table_output():
    columns = ['TabletId', 'TabletType', 'TabletChannel', 'StoragePool', 'GroupId', 'GroupType', 'Size', 'TabletMaxSize']

    def human_readable_fn(d):
        return d.update((key, '%s GiB' % common.gib_string(d[key])) for key in ['Size', 'TabletMaxSize'] if key in d)

    def tablet_size_max(d, rg):
        sizes = [x['Size'] for x in rg]
        d.update(
            Size=sum(sizes),
            TabletMaxSize=max(sizes)
        )
        return d

    def aggr_size(d, rg):
        return d.update(Size=sum(x['Size'] for x in rg)) or d

    aggregations = {
        'tablet': (['TabletId', 'Size'], tablet_size_max),
        'tablet_type': (['TabletType', 'Size'], aggr_size),
        'channel': (['TabletChannel', 'Size'], aggr_size),
        'group': (['GroupId', 'Size'], aggr_size),
        'group_type': (['GroupType', 'Size'], aggr_size),
    }
    return table.TableOutput(
        cols_order=columns,
        human_readable_fn=human_readable_fn,
        aggregations=aggregations,
        aggr_drop={
            'Size',
            'TabletMaxSize',
        }
    )


table_output = create_table_output()


def add_options(p):
    p.add_argument('--cache-file', type=str, help='Path to the cache file')
    table_output.add_options(p)


def read_cache(args):
    try:
        with open(args.cache_file, 'r') as f:
            j = json.load(f)
        tablet_channel_group_stat = defaultdict(list)
        for row in j['sizes']:
            cols = ['tablet_id', 'tablet_channel', 'group_id', 'tablet_type', 'sp_name']
            tablet_channel_group_stat[tuple(map(row.__getitem__, cols))].append(row['size'])
        group_sizes_map = {}
        for key, value in j['group_sizes_map'].items():
            group_sizes_map[int(key)] = value
        return tablet_channel_group_stat, group_sizes_map
    except Exception as e:
        common.print_if_not_quiet(args, 'Failed to read data from cache file %s: %s' % (args.cache_file, e), file=sys.stderr)


def write_cache(args, tablet_channel_group_stat, group_sizes_map):
    j = dict(
        group_sizes_map=group_sizes_map,
        sizes=[
            {
                'tablet_id': tablet_id,
                'tablet_channel': tablet_channel,
                'group_id': group_id,
                'tablet_type': tablet_type,
                'sp_name': sp_name,
                'size': size,
            }
            for (tablet_id, tablet_channel, group_id, tablet_type, sp_name), sizes in tablet_channel_group_stat.items()
            for size in sizes
        ]
    )
    with open(args.cache_file, 'w') as f:
        json.dump(j, f, indent=2, sort_keys=True)


def do(args):
    tablet_channel_group_stat = None
    group_sizes_map = None

    if args.cache_file:
        res = read_cache(args)
        if res is not None:
            tablet_channel_group_stat, group_sizes_map = res
            common.print_if_verbose(args, 'Using data from cache file %s' % args.cache_file, file=sys.stderr)

    if tablet_channel_group_stat is None:
        base_config_and_storage_pools = common.fetch_base_config_and_storage_pools()
        base_config = base_config_and_storage_pools['BaseConfig']
        node_fqdn_map = common.build_node_fqdn_map(base_config)
        storage_pools = base_config_and_storage_pools['StoragePools']
        sp_map = common.build_storage_pool_names_map(storage_pools)

        group_to_sp_name = {
            g.GroupId: sp_map[g.BoxId, g.StoragePoolId]
            for g in base_config.Group
            if (g.BoxId, g.StoragePoolId) in sp_map
        }

        for group in base_config.Group:
            group_id = group.GroupId
            box_id = group.BoxId
            pool_id = group.StoragePoolId
            if (box_id, pool_id) not in sp_map:
                common.print_if_verbose(args, f"Can't find group {group_id} in box {box_id}, pool {pool_id}", sys.stderr)

        type_map = {
            int(row['TabletId']): row['Type']
            for row in common.fetch('viewer/json/tabletinfo', dict(enums=1)).get('TabletStateInfo', [])
            if 'TabletId' in row and 'Type' in row
        }

        group_sizes_map = {}
        host_requests_map = defaultdict(list)
        for group in base_config.Group:
            group_sizes_map[group.GroupId] = len(group.VSlotId)
            for vslot in group.VSlotId:
                host = node_fqdn_map[vslot.NodeId]
                host_requests_map[host].append((group.GroupId, vslot.NodeId, vslot.PDiskId, vslot.VSlotId))

        def fetcher(host, items, res_q):
            for group_id, node_id, pdisk_id, vslot_id in items:
                data = grouptool.parse_vdisk_storage(host, node_id, pdisk_id, vslot_id)
                for tablet_id, channel, size in data or []:
                    res_q.put((group_id, tablet_id, channel, size))
            res_q.put(None)

        processes = []
        res_q = multiprocessing.Queue()
        for key, value in host_requests_map.items():
            processes.append(multiprocessing.Process(target=fetcher, kwargs=dict(host=key, items=value, res_q=res_q), daemon=True))
        for p in processes:
            p.start()
        num_q = len(processes)
        tablet_channel_group_stat = defaultdict(list)
        while num_q:
            item = res_q.get()
            if item is None:
                num_q -= 1
                continue
            group_id, tablet_id, channel, size = item
            key = tablet_id, channel, group_id, type_map.get(tablet_id, ''), group_to_sp_name.get(group_id)
            tablet_channel_group_stat[key].append(size)
        for p in processes:
            p.join()

        if args.cache_file:
            write_cache(args, tablet_channel_group_stat, group_sizes_map)

    rows = []
    for (tablet_id, tablet_channel, group_id, tablet_type, sp_name), sizes in tablet_channel_group_stat.items():
        row = {}
        row['TabletId'] = tablet_id
        row['TabletType'] = tablet_type
        row['TabletChannel'] = tablet_channel
        row['GroupId'] = group_id
        row['GroupType'] = 'dynamic' if common.is_dynamic_group(group_id) else 'static'
        row['StoragePool'] = sp_name if common.is_dynamic_group(group_id) else 'None'
        row['Size'] = sum(sizes) * group_sizes_map[group_id] // len(sizes)
        rows.append(row)

    table_output.dump(rows, args)
